py-utilities
============

.. image:: https://badge.fury.io/py/py-utilities.svg
    :target: http://badge.fury.io/py/py-utilities

.. image:: https://travis-ci.org/ryankanno/py-utilities.png?branch=master
   :target: https://travis-ci.org/ryankanno/py-utilities

.. image:: https://coveralls.io/repos/ryankanno/py-utilities/badge.png
   :target: https://coveralls.io/r/ryankanno/py-utilities

Collection of useful python utilities.

Docs
----
They will end up somewhere.

License
-------
MIT
